@@ -112,7 +112,7 @@ def icon(icon_path, icon_name, size=None, color=None, extra_classes=None):
         cache_file = os.path.join(cache_path, cache_name)
         if os.path.exists(cache_file):
             # icon exists in cache, use that
-            with open(cache_file, 'r') as icon_file:
+            with open(cache_file, 'r', encoding="utf-8") as icon_file:
                 return icon_file.read()
 
     # cached icon doesn't exist or no cache configured, create and return icon
@@ -129,7 +129,7 @@ def icon(icon_path, icon_name, size=None, color=None, extra_classes=None):
         svg = render_svg(content, size, color, extra_classes)
         # if cache configured write icon to cache
         if cache_path and cache_file:
-            with open(cache_file, 'w') as icon_file:
+            with open(cache_file, 'w', encoding="utf-8") as icon_file:
                 icon_file.write(svg)
     except requests.ConnectionError:
         return getattr(
@@ -155,7 +155,7 @@ def bs_icon(icon_name, size=None, color=None, extra_classes=None):
     base_url = getattr(
         settings,
         'BS_ICONS_BASE_URL',
-        'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/',
+        'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.6.1/',
     )
     icon_path = f'{base_url}icons/{icon_name}.svg'
 
